use miette::IntoDiagnostic;

pub trait JsonToStdout: serde::Serialize {
    fn print_json(&self) -> miette::Result<()> {
        let json = serde_json::to_string(&self).into_diagnostic()?;
        println!("{json}");
        Ok(())
    }
}

impl<T: serde::Serialize> JsonToStdout for T {}
